#Hello world

This is an example project created by Sameer Bisht VIT Vellore. 22BEE0039
This contains two modules.
One module contains functions. and the other uses the functions from the first.

## Installation
Run the following to install:
'''python
pip install sameer22BEE0039
'''